@@ -102,6 +102,9 @@ class ArcMenuLayoutTweaksPage extends SubPage {
         case Constants.MenuLayout.SLEEK:
             this._loadSleekTweaks();
             break;
+        case Constants.MenuLayout.ZEST:
+            this._loadZestTweaks();
+            break;
         default:
             this._loadPlaceHolderTweaks();
             break;
@@ -722,11 +725,15 @@ class ArcMenuLayoutTweaksPage extends SubPage {
 
     _loadSleekTweaks() {
         const tweaksGroup = new Adw.PreferencesGroup();
+        this.add(tweaksGroup);
 
         tweaksGroup.add(this._createAvatarShapeRow());
         tweaksGroup.add(this._createSearchBarLocationRow());
         tweaksGroup.add(this._createFlipHorizontalRow());
 
+        const extraShortcutsGroup = new Adw.PreferencesGroup();
+        this.add(extraShortcutsGroup);
+
         const rightPanelWidthSpinButton = new Gtk.SpinButton({
             adjustment: new Gtk.Adjustment({
                 lower: 150, upper: 500, step_increment: 25, page_increment: 50, page_size: 0,
@@ -741,18 +748,14 @@ class ArcMenuLayoutTweaksPage extends SubPage {
             this._settings.set_int('sleek-layout-panel-width', widget.get_value());
         });
         const rightPanelWidthRow = new Adw.ActionRow({
-            title: _('Right-Panel Width'),
+            title: _('Extra Shortcuts Panel Width'),
             activatable_widget: rightPanelWidthSpinButton,
         });
         rightPanelWidthRow.add_suffix(rightPanelWidthSpinButton);
-        tweaksGroup.add(rightPanelWidthRow);
+        extraShortcutsGroup.add(rightPanelWidthRow);
 
-        this.add(tweaksGroup);
-
-        const extraShortcutsGroup = new Adw.PreferencesGroup();
         const extraShortcutsRow = this._createExtraShortcutsRow('sleek-layout-extra-shortcuts');
         extraShortcutsGroup.add(extraShortcutsRow);
-        this.add(extraShortcutsGroup);
     }
 
     _loadRedmondMenuTweaks() {
@@ -996,6 +999,42 @@ class ArcMenuLayoutTweaksPage extends SubPage {
         this.add(extraCategoriesLocationGroup);
     }
 
+    _loadZestTweaks() {
+        const tweaksGroup = new Adw.PreferencesGroup();
+        this.add(tweaksGroup);
+        tweaksGroup.add(this._createActivateOnHoverRow());
+        tweaksGroup.add(this._createAvatarShapeRow());
+        tweaksGroup.add(this._createFlipHorizontalRow());
+        tweaksGroup.add(this._disableAvatarRow());
+        tweaksGroup.add(this._createVertSeparatorRow());
+
+        const extraShortcutsGroup = new Adw.PreferencesGroup();
+        this.add(extraShortcutsGroup);
+
+        const rightPanelWidthSpinButton = new Gtk.SpinButton({
+            adjustment: new Gtk.Adjustment({
+                lower: 150, upper: 500, step_increment: 25, page_increment: 50, page_size: 0,
+            }),
+            climb_rate: 25,
+            valign: Gtk.Align.CENTER,
+            digits: 0,
+            numeric: true,
+        });
+        rightPanelWidthSpinButton.set_value(this._settings.get_int('zest-layout-panel-width'));
+        rightPanelWidthSpinButton.connect('value-changed', widget => {
+            this._settings.set_int('zest-layout-panel-width', widget.get_value());
+        });
+        const rightPanelWidthRow = new Adw.ActionRow({
+            title: _('Extra Shortcuts Panel Width'),
+            activatable_widget: rightPanelWidthSpinButton,
+        });
+        rightPanelWidthRow.add_suffix(rightPanelWidthSpinButton);
+        extraShortcutsGroup.add(rightPanelWidthRow);
+
+        const extraShortcutsRow = this._createExtraShortcutsRow('zest-layout-extra-shortcuts');
+        extraShortcutsGroup.add(extraShortcutsRow);
+    }
+
     _createWidgetsRows(layout) {
         let weatherWidgetSetting = 'enable-weather-widget-raven';
         let clockWidgetSetting = 'enable-clock-widget-raven';
